#
# spec file for package yt-dlp
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%define skip_python36 1
%define skip_python37 1
%if 0%{?suse_version} < 1600
%global pythons python312
%endif

Name:           yt-dlp
Version:        2025.03.31
Release:        1.1
Summary:        Enhanced fork of youtube-dl, a video site downloader for offline watching
License:        CC-BY-SA-3.0 AND SUSE-Public-Domain
Group:          Productivity/Networking/Web/Utilities
URL:            https://github.com/yt-dlp/yt-dlp
Source:         https://github.com/yt-dlp/yt-dlp/releases/download/%version/yt-dlp.tar.gz
Source9:        yt-dlp-rpmlintrc
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  make >= 4
BuildRequires:  python-rpm-macros
BuildRequires:  zip
BuildArch:      noarch
Obsoletes:      yt-dlp-bash-completion < %version-%release
Provides:       yt-dlp-bash-completion = %version-%release
Obsoletes:      yt-dlp-fish-completion < %version-%release
Provides:       yt-dlp-fish-completion = %version-%release
Obsoletes:      yt-dlp-zsh-completion < %version-%release
Provides:       yt-dlp-zsh-completion = %version-%release
%if 0%{?suse_version} < 1600
Requires:       python312-yt-dlp = %version
%else
Requires:       python3-yt-dlp = %version
%endif
%define python_subpackage_only 1
%python_subpackages

%description
yt-dlp is a command-line program to retrieve videos from
YouTube.com and other video sites for later watching.

%package -n yt-dlp-youtube-dl
Summary:        Compat symlinks for youtube-dl
Requires:       yt-dlp
Provides:       youtube-dl
Conflicts:      youtube-dl

%description -n yt-dlp-youtube-dl
This package installs "youtube-dl" as a symlink to yt-dlp.

%package -n python-yt-dlp
Summary:        yt-dlp Python library
Group:          Development/Languages/Python
Requires:       ffmpeg
Suggests:       python-Brotli
Suggests:       python-certifi
Suggests:       python-mutagen
Suggests:       python-pycryptodomex
Suggests:       python-websockets

%description -n python-yt-dlp
The direct Python interface into yt-dlp.

%prep
%autosetup -p1 -n %name

%build
rm -f youtube-dl yt-dlp
#
# A self-decompressing yt-dlp is built only when python_build is not
# exercised; else yt-dlp is a loader.
#
%pyproject_wheel
%make_build yt-dlp

%install
b="%buildroot"
%pyproject_install
ln -s yt-dlp "$b/%_bindir/youtube-dl"
rm -Rf "$b/%_datadir/doc"
# if you leave everything as-is, rpmlint complains about
# 	python312-yt-dlp.noarch: W: files-duplicate
# 	/usr/lib/python3.12/site-packages/yt_dlp/utils/__pycache__/progress.cpython-312.pyc
# 	/usr/lib/python3.12/site-packages/yt_dlp/utils/__pycache__/progress.cpython-312.opt-1.pyc
# if you add fdupes, rpmlint complains about
# 	python312-yt-dlp.noarch: E: python-bytecode-inconsistent-mtime
# 	/usr/lib/python3.12/site-packages/yt_dlp/extractor/__pycache__/screencastomatic.cpython-312.pyc
# 	2024-09-29T18:11:02
# 	/usr/lib/python3.12/site-packages/yt_dlp/extractor/screencastomatic.py
# 	2024-09-29T18:11:01

%files -n yt-dlp
%license LICENSE
%doc README.md
%_bindir/%name
%_mandir/man1/%name.1%ext_man
%_datadir/bash-completion/
%_datadir/fish/
%_datadir/zsh/

%files -n yt-dlp-youtube-dl
%_bindir/youtube-dl

%files %{python_files yt-dlp}
%python_sitelib/y*

%changelog
* Mon Mar 31 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 2025.03.31
  * yt: add player_js_variant extractor-arg
  * yt/tab: Fix playlist continuation extraction
* Fri Mar 28 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 2025.03.27
  * youtube: Make signature and nsig extraction more robust
* Wed Mar 26 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 2025.03.26
  * youtube: fix signature and nsig extraction for player 4fcd6e4a
* Sat Mar 22 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 2025.03.21
  * Fix external downloader availability when using
    ``--ffmpeg-location``
  * youtube: fix nsig and signature extraction for player 643afba4.
* Fri Feb 28 2025 Jan Engelhardt <jengelh@inai.de>
- Require same version between yt-dlp -> python-yt-dlp
* Wed Feb 19 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 2025.02.19
  * NSIG workaround for tce player JS
* Sun Jan 26 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 2025.01.26
  * bilibili: Support space video list extraction without login
  * crunchyroll: Remove extractors
  * youtube: Download tv client Innertube config
  * youtube: Use different PO token for GVS and Player
* Thu Jan 16 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 2025.01.15
  * youtube: Do not use web_creator as a default client
* Mon Jan 13 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 2025.01.12
  * yt: fix DASH formats incorrectly skipped in some situations
  * yt: refactor cookie auth
* Wed Dec 25 2024 Luigi Baldoni <aloisio@gmx.com>
- Fix 15.6 build
* Tue Dec 24 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2024.12.23
  * yt: add age-gate workaround for some embeddable videos
* Fri Dec 13 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2024.12.13
  * yt: fix signature function extraction for 2f1832d2
  * yt: prioritize original language over auto-dubbed audio
* Thu Dec 12 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2024.12.06
  * yt: fix ``n`` sig extraction for player 3bb1f723
  * yt: fix signature function extraction
  * yt: player client maintenance
* Tue Dec  3 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2024.12.03
  * bilibili: Always try to extract HD formats
  * youtube: Adjust player clients for site changes
* Tue Nov 19 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2024.11.18
  * cloudflarestream: Avoid extraction via videodelivery.net
  * youtube: remove broken OAuth support
* Mon Nov  4 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2024.11.04
  * Prioritize AV1
  * Remove Python <= 3.8 support
  * youtube: Adjust OAuth refresh token handling
* Wed Oct 23 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2024.10.22
  * yt: Remove broken android_producer client
  * yt: Remove broken age-restriction workaround
  * yt: Support logging in with OAuth
* Tue Oct  8 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2024.10.07
  * Fix cookie load error handling
  * youtube: Change default player clients to ios,mweb
  * patreon: Extract all m3u8 formats for locked posts
* Sun Sep 29 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2024.09.27
  * Support excluding player_clients in extractor-arg
  * clip: Prioritize https formats
* Tue Aug 13 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2024.08.06
  * youtube: Fix `n` function name extraction for player `b12cc44b`
* Tue Aug 13 2024 Jan Engelhardt <jengelh@inai.de>
- Merge sh completion packages into main package
- Add yt-dlp-youtube-dl subpackage
* Thu Aug  1 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2024.08.01
  * youtube:
  * Change default player clients to ios,tv
  * Fix n function name extraction for player 20dfca59
  * Fix age-verification workaround
* Thu Jul 25 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2024.07.25
  * youtube: Fix n function name extraction for player 3400486c
* Wed Jul 17 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2024.07.16
  * Support auto-tty and no_color-tty for --color
  * youtube: Avoid poToken experiment player responses
* Wed Jul 10 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2024.07.09
  * youtube: Remove broken n function extraction fallback
* Tue Jul  2 2024 Michael Vetter <mvetter@suse.com>
- Update to release 2024.07.01:
  * Properly sanitize file-extension to prevent file system
    modification and RCE. Unsafe extensions are now blocked from
    being downloaded. [CVE-2024-38519 boo#1227305]
* Tue May 28 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2024.05.27
  * Fix parsing of base URL in SMIL manifest
* Mon May 27 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2024.05.26
  * Better warning when requested subs format not found
  * Warn if lack of installed ffmpeg alters format selection
  * youtube: Add mediaconnect client
* Tue Apr  9 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2024.04.09
  * Add new option --progress-delta, --impersonate,
  - -list-impersonate-targets, --no-break-on-existing.
  * Infer acodec for single-codec containers
  * Prevent RCE when using --exec with %%q (CVE-2024-22423)
* Sun Mar 10 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2024.03.10
  * Add --compat-options 2023
  * Don't select storyboard formats as fallback
  * Handle --load-info-json format selection errors
  * webvtt: Don't parse single fragment files
* Sun Dec 31 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2023.12.30
  * ard: Overhaul extractors
  * facebook: Fix Memories extraction
  * youtube: Fix like_count extraction
  * youtube:Improve detection of faulty HLS formats
* Thu Nov 16 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2023.11.16
  * Add extractors for eltrecetv and jiosaavn.
* Tue Nov 14 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2023.11.14
  * Security: [CVE-2023-46121] Patch Generic Extractor MITM
    Vulnerability via Arbitrary Proxy Injection
  * Disallow smuggling of arbitrary http_headers; extractors now
    only use specific headers
* Sun Nov  5 2023 Jan Engelhardt <jengelh@inai.de>
- Make yt-dlp require the one pythonXX-yt-dlp that /usr/bin/yt-dlp
  was built with.
* Fri Oct 27 2023 Daniel Garcia <daniel.garcia@suse.com>
- Use python_subpackage_only to build the pythonXXX-yt-dlp
  subpackages.
* Wed Oct 25 2023 Jan Engelhardt <jengelh@inai.de>
- Rework Python build procedure [boo#1216467]
* Sun Oct 22 2023 Jan Engelhardt <jengelh@inai.de>
- Enable Python library [boo#1216467]
* Fri Oct 13 2023 Ich <jengelh@inai.de>
- Update to release 2023.10.13
  * youtube: fix some bug with --extractor-retries inf
* Sat Oct  7 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2023.10.07
  * yt: Fix heatmap extraction
  * yt: Raise a warning for Incomplete Data instead of an error
* Sun Sep 24 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2023.09.24
  * Extract subtitles from SMIL manifests
  * fb: Add dash manifest URL
  * crunchyroll: Remove initial state extraction
  * youtube: Add player_params extractor arg
* Mon Sep 11 2023 Dirk Müller <dmueller@suse.com>
- remove suggests on brotlicffi - this is only for != cpython
* Fri Jul  7 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2023.07.06
  * Prevent Cookie leaks on HTTP redirect [boo#1213124] [CVE-2023-35934]
  * yt: Avoid false DRM detection
  * yt: Process post_live over 2 hours
  * yt: Support shorts-only playlists
* Thu Jun 22 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2023.06.22
  * youtube: add IOS to default clients used
* Wed Jun 21 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2023.06.21
  * Add option --compat-option playlist-match-filter
  * Add options --no-quiet, option --color, --netrc-cmd, --xff
  * Auto-select default format in -f-
  * Improve HTTP redirect handling
  * Support decoding multiple content encodings
* Tue May  9 2023 Max Lin <mlin@suse.com>
- Use python3.11 on Leap 15.5
  * python3.11 is the only python3 > 3.6 version would be shipped
    in Leap 15.5
* Sun Mar  5 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2023.03.04
  * A bunch of extractor fixes
* Fri Mar  3 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2023.03.03
  * youtube: Construct dash formats with range query
  * yt: Detect and break on looping comments
  * yt: Extract channel view_count when /about tab is passed
* Sat Feb 18 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to release 2023.02.17
  * Merge youtube-dl: Upto commit/2dd6c6e (Feb 17 2023)
  * Fix --concat-playlist
  * Imply --no-progress when --print
  * Improve default subtitle language selection
  * Make title completely non-fatal
  * Sanitize formats before sorting
  * [hls] Allow extractors to provide AES key
  * [extractor/generic] Avoid catastrophic backtracking in KVS regex
  * [jsinterp] Support if statements
  * [plugins] Fix zip search paths
  * [utils] Don't use Content-length with encoding
  * [utils] Fix time_seconds to use the provided TZ
  * [utils] Fix race condition in make_dir
  * [extractor/anchorfm] Add episode
  * [extractor/boxcast] Add extractor
  * [extractor/ebay] Add extractor
  * [extractor/hypergryph] Add extractor
  * [extractor/NZOnScreen] Add extractor
  * [extractor/rozhlas] Add extractor
  * [extractor/tempo] Add IVXPlayer extractor
  * [extractor/txxx] Add extractors
  * [extractor/vocaroo] Add extractor
  * [extractor/wrestleuniverse] Add extractors
  * [extractor/yappy] Add extractor
  * [extractor/youtube] Fix uploader_id extraction
  * [extractor/youtube] Add hyperpipe instances
  * [extractor/youtube] Handle consent.youtube
  * [extractor/youtube] Support /live/ URL
  * [extractor/youtube] Update invidious and piped instances
  * [extractor/91porn] Fix title and comment extraction
  * [extractor/AbemaTV] Cache user token whenever appropriate
  * [extractor/bfmtv] Support rmc prefix
  * [extractor/biliintl] Add intro and ending chapters
  * [extractor/clyp] Support wav
  * [extractor/crunchyroll] Add intro chapter
  * [extractor/crunchyroll] Better message for premium videos
  * [extractor/crunchyroll] Fix incorrect premium-only error
  * [extractor/DouyuTV] Use new API
  * [extractor/embedly] Embedded links may be for other extractors
  * [extractor/freesound] Workaround invalid URL in webpage
  * [extractor/GoPlay] Use new API
  * [extractor/Hidive] Fix subtitles and age-restriction
  * [extractor/huya] Support HD streams
  * [extractor/moviepilot] Fix extractor
  * [extractor/nbc] Fix NBC and NBCStations extractors
  * [extractor/nbc] Fix XML parsing
  * [extractor/nebula] Remove broken cookie support
  * [extractor/nfl] Add NFLPlus extractor
  * [extractor/niconico] Add support for like history
  * [extractor/nitter] Update instance list by OIRNOIR
  * [extractor/npo] Fix extractor and add HD support
  * [extractor/odkmedia] Add OnDemandChinaEpisodeIE
  * [extractor/pornez] Handle relative URLs in iframe
  * [extractor/radiko] Fix format sorting for Time Free
  * [extractor/rcs] Fix extractors
  * [extractor/reddit] Support user posts
  * [extractor/rumble] Fix format sorting
  * [extractor/servus] Rewrite extractor
  * [extractor/slideslive] Fix slides and chapters/duration
  * [extractor/SportDeutschland] Fix extractor
  * [extractor/Stripchat] Fix extractor
  * [extractor/tnaflix] Fix extractor
  * [extractor/tvp] Support stream.tvp.pl
  * [extractor/twitter] Fix --no-playlist and add media
    view_count when using GraphQL
  * [extractor/twitter] Fix graphql extraction on some tweets
  * [extractor/vimeo] Fix playerConfig extraction
  * [extractor/viu] Add ViuOTTIndonesiaIE extractor
  * [extractor/vk] Fix playlists for new API
  * [extractor/vlive] Replace with VLiveWebArchiveIE
  * [extractor/ximalaya] Update album _VALID_URL
  * [extractor/zdf] Use android API endpoint for UHD downloads
* Fri Jan  6 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2023.01.06
  * extractor/youtube: Retry manifest refresh for live-from-start
* Mon Jan  2 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2023.01.02
  * Add `--compat-options 2021,2022`
  * Native progress for aria2c via RPC
  * Merge youtube-dl: Upto commit/195f22f (2022-11-13)
  * Add `weba` and `ac4` to the list of recognized codecs
* Fri Nov 11 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2022.11.11
  * Merge youtube-dl code up to 20221104
  * Do more processing in --flat-playlist
  * Fix --list options not implying -s in some cases
  * downloader: let HLS continue without first fragment
* Tue Oct  4 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2022.10.04
  * Allow open ranges for time ranges
  * Allow plugin extractors to replace the built-in ones
  * New extractors
  * youtube: download post_live videos from start
  * youtube: add support for Shorts audio pivot feed
* Thu Sep  1 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2022.09.01
  * Add a few extractors
* Fri Aug 19 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2022.08.19
  * jsinterp: Fix for new youtube players and related
    improvements
  * extractor/youtube: Fix error reporting of "Incomplete data"
  * extractor/youtube: Improve format sorting for IOS formats
* Sun Aug 14 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2022.08.14
  * Merge youtube-dl upto commit d231b56
* Fri Aug 12 2022 Luigi Baldoni <aloisio@gmx.com>
- Drop redundant runtime requirements
- Differentiate requirements between 15.3 and 15.4
- Add optional runtime requirements for Tumbleweed
* Wed Aug 10 2022 Luigi Baldoni <aloisio@gmx.com>
- Force python 3.9 on anything older than Tumbleweed
* Tue Aug  9 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2022.08.08
  * Remove Python 3.6 support
  * Merge youtube-dl upto commit adb5294
  * Reject entire playlists faster with `--match-filter`
  * youtube: Fixes for third party client detection
* Mon Jul 18 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2022.07.18
  * youtube: Fix duration check for post-live manifestless mode
* Wed Jun 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2022.06.29
  * Fix --downloader native
  * Fix section_end of clips
  * Fix playlist error handling
* Wed Jun 22 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2022.06.22.1
  * Add option --download-sections
  * extractor/youtube: Support downloading clips
  * Add slicing notation to --playlist-items
* Fri May 20 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2022.05.18
  * Add support for SSL client certificate authentication
  * Add --match-filter - to interactively ask for each video
* Fri Apr  8 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2022.04.08
  * Treat multiple --match-filters as OR
  * De-prioritize automatic-subtitles when no --sub-lang is given
* Tue Mar  8 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2022.03.08.1
  * Add regex operator and quoting to format filters
  * Add brotli content-encoding support
* Fri Feb  4 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2022.02.04
  * twitcasting: Enforce UTF-8 for POST payload
* Thu Feb  3 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2022.02.03
  * Add option --print-to-file
  * youtube:api: Do not use seek when reading HTTPError response
* Fri Jan 21 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2022.01.21
  * Add option --concat-playlist to concat videos in a playlist
  * Add extractors for some 20 sites
  * zdf: add chapter extraction
* Tue Dec 28 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Tweak spec, use current syntax for Supplements.
* Tue Dec 28 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.12.27
  * Avoid recursion error when re-extracting info
  * Fix position of `--ppa` option when calling ffmpeg
* Sat Dec 25 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.12.25
  * Add extractor for TrueID
* Wed Dec  1 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.12.01
  * Add option --wait-for-video to wait for scheduled streams
  * Clarify video/audio-only formats in -F
* Mon Nov 29 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.11.10.1
  * Fix youtube throttling by decrypting n-sig
  * Separate --check-all-formats from --check-formats
  * Add negative option --no-batch-file
  * Allow duration strings in --match-filter
- Drop ceskatelevize_fix_POST_request.patch (inapplicable)
* Sun Oct 31 2021 Matej Cepl <mcepl@suse.com>
- Add ceskatelevize_fix_POST_request.patch to fix
  gh#ytdl-org/youtube-dl#30172.
* Sun Oct 31 2021 Matej Cepl <mcepl@suse.com>
- Update to 2021.10.22:
  - [docs] Migrate issues to use forms by Ashish0804
  - [downloader] Fix slow progress hooks
  - This was causing HLS/DASH downloads to be extremely slow in some situations
  - [downloader/ffmpeg] Improve simultaneous download and merge
  - [EmbedMetadata] Allow overwriting all default metadata with meta_default key
  - [ModifyChapters] Add ability for --remove-chapters to remove sections by timestamp
  - [utils] Allow duration strings in --match-filter
  - Add HDR information to formats
  - Add negative option --no-batch-file by Zirro
  - Calculate more fields for merged formats
  - Do not verify thumbnail URLs unless --check-formats is specified
  - Don't create console for subprocesses on Windows
  - Fix --restrict-filename when used with default template
  - Fix check_formats output being written to stdout when -qv
  - Fix bug in storyboards
  - Fix conflict b/w id and ext in format selection
  - Fix verbose head not showing custom configs
  - Load archive only after printing verbose head
  - Make duration_string and resolution available in --match-filter
  - Re-implement deprecated option --id
  - Reduce default --socket-timeout
  - Write verbose header to logger
  - [outtmpl] Fix bug in expanding environment variables
  - [cookies] Local State should be opened as utf-8
  - [extractor,utils] Detect more codecs/mimetypes
  - [extractor] Detect EXT-X-KEY Apple FairPlay
  - [utils] Use importlib to load plugins by sulyi
  - [http] Retry on socket timeout and show the last encountered error
  - [fragment] Print error message when skipping fragment
  - [aria2c] Fix --skip-unavailable-fragment
  - [SponsorBlock] Obey extractor-retries and sleep-requests
  - [Merger] Do not add aac_adtstoasc to non-hls audio
  - [ModifyChapters] Do not mutate original chapters by nihil-admirari
  - [devscripts/run_tests] Use markers to filter tests by sulyi
  - [7plus] Add cookie based authentication by nyuszika7h
  - [AdobePass] Fix RCN MSO by jfogelman
  - [CBC] Fix Gem livestream by makeworld-the-better-one
  - [CBC] Support CBC Gem member content by makeworld-the-better-one
  - [crunchyroll] Add season to flat-playlist Closes #1319
  - [crunchyroll] Add support for beta.crunchyroll URLs and fix series URLs with language code
  - [EUScreen] Add Extractor by Ashish0804
  - [Gronkh] Add extractor by Ashish0804
  - [hidive] Fix typo
  - [Hotstar] Mention Dynamic Range in format_id by Ashish0804
  - [Hotstar] Raise appropriate error for DRM
  - [instagram] Add login by u-spec-png
  - [instagram] Show appropriate error when login is needed
  - [microsoftstream] Add extractor by damianoamatruda, nixklai
  - [on24] Add extractor by damianoamatruda
  - [patreon] Fix vimeo player regex by zenerdi0de
  - [SkyNewsAU] Add extractor by Ashish0804
  - [tagesschau] Fix extractor by u-spec-png
  - [tbs] Add tbs live streams by llacb47
  - [tiktok] Fix typo and update tests
  - [trovo] Support channel clips and VODs by Ashish0804
  - [Viafree] Add support for Finland by 18928172992817182
  - [vimeo] Fix embedded player.vimeo
  - [vlive:channel] Fix extraction by kikuyan, pukkandan
  - [youtube] Add auto-translated subtitles
  - [youtube] Expose different formats with same itag
* Fri Oct 15 2021 Jan Engelhardt <jengelh@inai.de>
- Switch to yt-dlp 2021.10.10 codebase
  * Address youtube download speed being capped at 80KB/s
* Sun Jun 27 2021 Matej Cepl <mcepl@suse.com>
- Update to 2021.06.06
  * [facebook] Improve login required detection
  * [youporn] Fix formats and view count extraction
  * [orf:tvthek] Fix thumbnails extraction
  * [formula1] Fix extraction
  * [ard] Relax URL regular expression and fix video ids
  * [ustream] Detect https embeds
  * [ted] Prefer own formats over external sources
  * [twitch:clips] Improve extraction
  * [twitch:clips] Add access token query to download URLs
  * [youtube] Fix get_video_info request
  * [vimeo] Fix vimeo pro embed extraction
  * [redbulltv] Fix embed data extraction
  * [shahid] Relax URL regular expression
* Thu May 20 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.05.16
  * Add support for sibnet embeds
* Fri Apr 16 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.04.17
  * [curiositystream] fix format extraction
  * [cbssports] fix extraction
  * [mtv] Fix Viacom A/B Testing Video Player extraction
  * [youtube:tab] Pass innertube context and x-goog-visitor-id
    header along with continuation requests
  * [youtube] Improve URL to extractor routing
  * [youtube] Add more invidious instances
  * [youtube:tab] Detect series playlist on playlists page
  * [youtube:tab] Improve grid extraction
  * [youtube] Improve stretch extraction and fix stretched ratio
    calculation
  * [utils] Add support for support for experimental HTTP
    response status code 308 Permanent Redirect
* Tue Apr  6 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.04.07
  * youtube: Add support for hashtag videos extraction
* Wed Mar 31 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.04.01
  * youtube: fix playlist/comunity continuation items extraction
  * vimeo: fix unlisted video extraction
  * youtube: fix video's channel extraction
  * youtube: imporve age-restricted video extraction
  * youtube: setup CONSENT cookie when needed
* Sat Mar 27 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.03.25
  * Improve extraction for RTVE, Applepodcasts, SVTPlay
* Sun Mar 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.03.14
  * voxmedia: fix volume embed extraction
  * cbs: add support for Paramount+
  * southpark: Fix extraction and add support for
    southparkstudios.com
* Wed Mar  3 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.03.03
  * bbc: add support for BBC Reel videos
* Mon Mar  1 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.03.02
  * youtube: fix get_video_info request
  * zdf: Rework extractors
* Sun Feb 21 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.02.22
  * vimeo: Add support for unlisted video source format extraction
  * youtube: Fix uploader extraction in flat playlist mode
* Wed Feb 10 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.02.10
  * youtube: Add support for phone/tablet JS player
  * youtube: Extract ABR and VBR
* Wed Feb  3 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.02.04
  * medialaan: add support DPG Media MyChannels based websites
  * youtube: improve DASH formats file size extraction
* Sun Jan 24 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.01.24.1
  * aol: add support for yahoo videos
  * yahoo: fix single video extraction
  * aljazeera: fix extraction
  * ard: Fix title and description extraction and update tests
  * spotify: Add new extractor for Spotify Podcasts
* Sat Jan 16 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.01.16
  * Protect from infinite recursion due to recursively nested
    playlists
* Sun Jan 10 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.01.08
  * twitter: Add support for summary card
* Sun Jan  3 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.01.03
  * sky: add support for Sports News articles and Brighcove videos
* Wed Dec 30 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.12.31
  * Allow format filtering using audio language
* Mon Dec 28 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.12.29
  * Added support for FXNetworks, live.mewatch.sg, zype/uplynk.
* Tue Dec 22 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.12.22
  * nhk: Add support for NHK video programs, audio programs and
    program clips
  * Add support for music.yandex.com, more.tv
* Sun Dec 13 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.12.14
  * youtube: Add some invidious instances
  * itv: clean description from HTML tags
  * linuxacademy] Fix authentication and extraction
  * downloader/hls] delegate manifests with media initialization
    to ffmpeg
* Sat Dec 12 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.12.12
  * Updates to Facebook video extraction
* Wed Dec  9 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.12.09
  * slideslive: Add support for yoda service videos and
    extract subtitles
  * youtube:tab: Capture and output alerts
  * telequebec: Fix Extraction and Add Support for
    video.telequebec.tv
* Sun Dec  6 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.12.07
  * peertube: Recognize audio-only formats
  * nrk: reduce requests for Radio series
* Fri Dec  4 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.12.05
  * gamespot: Extract DASH and HTTP formats
  * zdf: extract webm formats
  * nrk: improve format extraction and geo-restriction detection
* Tue Dec  1 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.12.02
  * yandexmusic: Refactor and add support for artist's tracks
    and albums
  * mediaset: add support for movie URLs
  * youtube: Improve age-gated videos extraction
* Sun Nov 29 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.11.29
  * youtube: Improve yt initial player response extraction
* Wed Nov 25 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.11.26
  * cda, nrk: fix extraction
  * youtube: improve music metadata and license extraction
  * medaltv: Add new extractor
  * bbc: fix BBC News videos extraction, BBC Three clip extraction
  * vlive: Add support for post URLs
* Mon Nov 23 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.11.24
  * pinterest: Add extractor
  * extractor/common: add generic support for akamai http format
    extraction
  * skyit: add support for multiple Sky Italia websites
  * pinterest: Add support for large collections (more than 25
    pins)
* Sat Nov 21 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.11.21.1
  * amara: add new extractor
  * discoverynetworks: add support new TLC/DMAX URLs
  * youtube: Improve yt initial data extraction
  * YoutubeDL: Fix --ignore-errors for playlists with
    generator-based entries of url_transparent
  * youtube:tab: Add support for current video and fix lives
    extraction
  * svtplay: Add support for svt.se/barnkanalen
* Wed Nov 18 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.11.19
  * arte: Extract m3u8 formats
  * mgtv: fix format extraction
* Tue Nov 17 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.11.18
  * francetv: Add fallback video URL extraction
* Mon Nov 16 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.11.17
  * Fix extraction for RaiPlay, vlive, usanetwork, nbc, cnbc,
    bandcamp
  * Add support for pm-wissen.com
* Mon Nov  2 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.11.01.1
  * youtube: Fix JS player URL extraction
  * ytsearch: Fix extraction
  * ustream: Add support for video.ibm.com
  * expressen: Add support for di.se
* Sun Sep 20 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.09.20
  * telequebec: Add support for brightcove videos
* Mon Sep 14 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.09.14
  * googledrive: Use redirect URLs for source format
* Sun Sep  6 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.09.06
  * nrktv: Improve video id extraction
  * youtube Fix age gate content detection
  * svtplay: Fix svt id extraction
  * twitch: Rework extractors
* Tue Jul 28 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to release 2020.07.28
  * [youtube] Fix sigfunc name extraction
  * [youtube] Improve description extraction
  * [wistia] Restrict embed regular expression
  * [youtube] Prevent excess HTTP 301
  * [youtube:playlists] Extend URL regular expression
  * [bellmedia] Add support for cp24.com clip URLs
  * [brightcove] Improve embed detection
* Sun Jun 28 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to release 2020.06.16.1
  * [youtube] Force old layout (#25682, #25683, #25680, #25686)
  * [youtube] Fix categories and improve tags extraction
- Update to version 2020.06.16
  * [youtube] Fix uploader id and uploader URL extraction
  * [youtube] Improve view count extraction
  * [youtube] Fix upload date extraction (#25677)
  * [youtube] Fix thumbnails extraction (#25676)
  * [youtube] Fix playlist and feed extraction (#25675)
  * [facebook] Add support for single-video ID links
  * [youtube] Extract chapters from JSON (#24819)
  * [kaltura] Add support for multiple embeds on a webpage (#25523)
* Sat Jun  6 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.06.06
  * jwplatform: Improve embeds extraction
  * brightcove: Fix subtitles extraction
  * twitch: Pass v5 accept header and fix thumbnails extraction
* Fri May 29 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.05.29
  * youtube: Add support for more invidious instances
* Fri May  8 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.05.08
  * downloader/http: Finish downloading once received data length
    matches expected
  * orf: Add support for more radio stations
  * utils: Improve cookie files support
* Sat May  2 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.05.03
  * extractor/common] Skip malformed ISM manifest XMLs while
    extracting ISM formats
  * soundcloud: Extract AAC format
  * prosiebensat1: Extract series metadata
  * youtube: Use redirected video id if any
* Mon Mar 23 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.03.24
  * cbc:watch: Add support for authentication
  * cbc:watch: Fix authenticated device token caching
  * soundcloud: fix download url extraction
* Sun Mar  8 2020 Martin Rey <mrey@suse.com>
- Update to release 2020.03.08
  * core
  * utils: Add support for cookie files with spaces
  * extractors
  * pornhub: Add support for pornhubpremium.com (#24288)
  * youtube: Remove outdated code and unnecessary requests
  * youtube: Improve extraction in 429 HTTP error conditions
    (#24283)
  * nhk: Update API version (#24270)
* Fri Mar  6 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.03.06
  * servus: added support for new URL schema
  * youtube: fixed age-gated videos support without login
* Mon Mar  2 2020 Martin Rey <mrey@suse.com>
- Update to release 2020.03.01
  * Core
  * [YoutubeDL] Force redirect URL to unicode on python 2
  * [options] Remove duplicate short option -v for --version
    (#24162)
  * Extractors
  * [xhamster] Fix extraction (#24205)
  * [franceculture] Fix extraction (#24204)
  * [telecinco] Add support for article opening videos
  * [telecinco] Fix extraction (#24195)
  * [xtube] Fix metadata extraction (#21073, #22455)
  * [youjizz] Fix extraction (#24181)
  * Remove no longer needed compat_str around geturl
  * [pornhd] Fix extraction (#24128)
  * [teachable] Add support for multiple videos per lecture
    (#24101)
  * [wistia] Add support for multiple generic embeds
    (#8347, 11385)
  * [imdb] Fix extraction (#23443)
  * [tv2dk:bornholm:play] Fix extraction (#24076)
* Sun Feb 16 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.02.16
  * sportdeutschland] Update to new sportdeutschland API
  * toggle: Add support for mewatch.sg
  * npr: Add support for streams
* Thu Jan 23 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.01.24
  * 24video: add support for 24video.vip
  * nbc: add support for nbc multi network URLs
* Tue Jan 14 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.01.15
  * scrippsnetworks: add support for www.discovery.com videos
  * twitter: add support for promo_video_website cards
  * vodplatform: add support for embed.kwikmotion.com domain
* Tue Dec 31 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.01.01
  * soundcloud: fix client id extraction for non fatal requests
  * prosiebensat1: improve geo restriction handling
  * brightcove: cache brightcove player policy keys
  * scrippsnetworks: Add new extractor
  * mitele: fix extraction
  * soundcloud: Update client id
* Tue Dec 24 2019 Ismail Dönmez <idonmez@suse.com>
- Update to release 2019.12.25
  * [mediaset] Fix parse formats (#23508)
  * [tv2dk:bornholm:play] Add support for play.tv2bornholm.dk (#23291)
  * [slideslive] Add support for url and vimeo service names (#23414)
  * [slideslive] Fix extraction (#23413)
  * [twitch:clips] Fix extraction (#23375)
  * [soundcloud] Add support for token protected embeds (#18954)
  * [vk] Improve extraction
  * [kontrtube] Remove extractor
  * [videopremium] Remove extractor
  * [musicplayon] Remove extractor (#9225)
  * [ufctv] Add support for ufcfightpass.imgdge.com and
    ufcfightpass.imggaming.com (#23343)
  * [twitch] Extract m3u8 formats frame rate (#23333)
  * [imggaming] Add support for playlists and extract subtitles
  * [ufcarabia] Add support for UFC Arabia (#23312)
  * [ufctv] Fix extraction
  * [yahoo] Fix gyao brightcove player id (#23303)
  * [vzaar] Override AES decryption key URL (#17521)
  * [vzaar] Add support for AES HLS manifests (#17521, #23299)
  * [nrl] Fix extraction
  * [teachingchannel] Fix extraction
  * [nintendo] Fix extraction and partially add support for Nintendo Direct
    videos (#4592)
  * [ooyala] Add better fallback values for domain and streams variables
  * [youtube] Add support youtubekids.com (#23272)
  * [tv2] Detect DRM protection
  * [tv2] Add support for katsomo.fi and mtv.fi (#10543)
  * [tv2] Fix tv2.no article extraction
  * [msn] Improve extraction
  * [abcotvs] Relax URL regular expression and improve metadata extraction
    (#18014)
  * [channel9] Reduce response size
  * [adobetv] Improve extaction
* Thu Nov 28 2019 Sebastien CHAVAUX <seb95.scou@gmail.com>
- Update to release 2019.11.28
  * [utils] Add generic caesar cipher and rot47
  * [utils] Handle rd-suffixed day parts in unified_strdate (#23199)
  * [vimeo] Improve extraction
  * Fix review extraction
  * Fix ondemand extraction
  * Make password protected player case as an expected error (#22896)
  * Simplify channel based extractors code
  * [openload] Remove extractor (#11999)
  * [verystream] Remove extractor
  * [streamango] Remove extractor (#15406)
  * [dailymotion] Improve extraction
  * Extract http formats included in m3u8 manifest
  * Fix user extraction (#3553, #21415)
  * Add suport for User Authentication (#11491)
  * Fix password protected videos extraction (#23176)
  * Respect age limit option and family filter cookie value (#18437)
  * Handle video url playlist query param
  * Report allowed countries for geo-restricted videos
  * [corus] Improve extraction
  * Add support for Series Plus, W Network, YTV, ABC Spark, disneychannel.com
  and disneylachaine.ca (#20861)
  * Add support for self hosted videos (#22075)
  * Detect DRM protection (#14910, #9164)
  * [vivo] Fix extraction (#22328, #22279)
  * [bitchute] Extract upload date (#22990, #23193)
  * [soundcloud] Update client id (#23214)
* Thu Nov 21 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 2019.11.22
  * kinja: add support for Kinja embeds
  * twitch: add support for Clip embed URLs
  * nexx: Add support for Multi Player JS Setup
  * drtv: Add support for new URL schema
* Mon Nov  4 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 2019.11.05
  * tv2dk: Add extractor
  * yahoo: restore support for cbs suffixed URLs
  * mixcloud: fix cloudcast data extraction
  * daum: fix VOD and Clip extracton
  * wistia: reduce embed extraction false positives and support
    inline embeds
  * bellmedia: add support for marilyn.ca videos
  * mediaset: extract unprotected M3U and MPD manifests
  * jamendo: restore track url modification
  * myspass: fix video URL extraction and improve metadata
    extraction
  * msn: add support for Vidible and AOL embeds
* Tue Oct 29 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 2019.10.29
  * globo: handle alternative hash signing method
  * facebook: extract subtitles
  * odnoklassniki: add support for Schemeless embed extraction
  * discoverynetworks: add support for dplay.co.uk
  * mtv: add support for mtvjapan.com
  * go: Add support for abc.com and freeform.com
* Mon Oct 21 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 2019.10.22
  * atresplayer: fix extraction
  * dumpert: fix extraction
  * mit: Remove support for video.mit.edu
  * twitch: update VOD URL matching
  * facebook: Bypass download rate limits
* Wed Oct 16 2019 Sebastien CHAVAUX <seb95.scou@gmail.com>
- Update to release 2019.10-16:
  * [extractor/common] Make _is_valid_url more relaxed
  * [vimeo] Improve album videos id extraction (#22599)
  * [globo] Extract subtitles (#22713)
  * [bokecc] Improve player params extraction (#22638)
  * [nexx] Handle result list (#22666)
  * [vimeo] Fix VHX embed extraction
  * [nbc] Switch to graphql API (#18581, #22693, #22701)
  * [vessel] Remove extractor
  * [promptfile] Remove extractor (#6239)
  * [kaltura] Fix service URL extraction (#22658)
  * [kaltura] Fix embed info strip (#22658)
  * [globo] Fix format extraction (#20319)
  * [redtube] Improve metadata extraction (#22492, #22615)
  * [pornhub:uservideos:upload] Fix extraction (#22619)
  * [telequebec:squat] Add support for squat.telequebec.tv (#18503)
  * [wimp] Remove extractor (#22088, #22091)
  * [gfycat] Extend URL regular expression (#22225)
  * [chaturbate] Extend URL regular expression (#22309)
  * [peertube] Update instances (#22414)
  * [telequebec] Add support for coucou.telequebec.tv (#22482)
  * [xvideos] Extend URL regular expression (#22471)
  * [youtube] Remove support for invidious.enkirton.net (#22543)
  * [openload] Add support for oload.monster (#22592)
  * [nrktv:seriebase] Fix extraction (#22596)
  * [youtube] Add support for yt.lelux.fi (#22597)
  * [orf:tvthek] Make manifest requests non fatal (#22578)
  * [teachable] Skip login when already logged in (#22572)
  * [viewlift] Improve extraction (#22545)
  * [nonktube] Fix extraction (#22544)
* Sat Sep 28 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 2019.09.28
  * tv4: Fix extraction and extract series metadata
  * zdf: Bypass geo restriction
  * brightcove: delegate all supported BrightcoveLegacyIE URLs to BrightcoveNewIE
  * mixcloud: allow uppercase letters in format URLs
  * instagram: add support for tv URLs
  * bilibili: add support audio albums and songs
  * youtube: Add support for invidious.drycat.fr
  * openload: Add support for oload.online
  * nhk: Add support for clips
* Wed Sep 11 2019 Fritz Reichwald <reichwald@b1-systems.de>
- Update to release 2019.09.12.1
  * nickjr: Add support for nickelodeonjunior.fr
  * youtube: Add support for invidious tor instances
* Sun Sep  1 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 2019.09.01
  * Add support for oload.vip, lequipe.fr, woof.tube
  * Add support for squarespace embeds
* Wed Aug 14 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2019.08.13
  * downloader/fragment: Fix ETA calculation of resumed download
  * discovery: extract series meta field
  * roosterteeth: add support for watch URLs
* Fri Aug  2 2019 Ismail Dönmez <idonmez@suse.com>
- Update to new upstream release 2019.08.02
  * [yahoo:japannews] Add support for yahoo.co.jp (#21698, #21265)
  * [discovery] Add support go.discovery.com URLs
  * [youtube:playlist] Relax video regular expression (#21844)
  * [generic] Restrict --default-search schemeless URLs detection pattern
    (#21842)
  * [vrv] Fix CMS signing query extraction (#21809)
  * [youtube] Fix and improve title and description extraction (#21934)
  * [tvigle] Add support for HLS and DASH formats (#21967)
  * [tvigle] Fix extraction (#21967)
  * [yandexvideo] Add support for DASH formats (#21971)
  * [discovery] Use API call for video data extraction (#21808)
  * [mgtv] Extract format_note (#21881)
  * [tvn24] Fix metadata extraction (#21833, #21834)
  * [dlive] Relax URL regular expression (#21909)
  * [openload] Add support for oload.best (#21913)
  * [youtube] Improve metadata extraction for age gate content (#21943)
* Tue Jul 16 2019 Sebastien CHAVAUX <seb95passionlinux@opensuse.org>
- Update to new upstream release 2019.07.16
  * [asiancrush] Add support for yuyutv.com, midnightpulp.com and cocoro.tv
  * (#21281, #21290)
  * [kaltura] Check source format URL (#21290)
  * [ctsnews] Fix YouTube embeds extraction (#21678)
  * [einthusan] Add support for einthusan.com (#21748, #21775)
  * [youtube] Add support for invidious.mastodon.host (#21777)
  * [gfycat] Extend URL regular expression (#21779, #21780)
  * [youtube] Restrict is_live extraction (#21782)
* Mon Jul  1 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2019.07.02
  * Introduce random_user_agent and use as default User-Agent (closes #21546)
  * dailymotion: add support embed with DM.player js call
  * openload: Add support for oload.biz
* Thu Jun 27 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2019.06.27
  * youtube: Add another signature function pattern
  * openload: Add support for oload.life
  * brightcove: Add support for playlists
  * beeg: Add support for api/v6 v2 URLs
* Mon Jun 24 2019 Sebastien CHAVAUX <seb95.scou@gmail.com>
- Update to new upstream release version 2019.06.21
  * [utils] Restrict parse_codecs and add theora as known vcodec (#21381)
  * [youtube] Update signature function patterns (#21469, #21476)
  * [youtube] Make --write-annotations non fatal (#21452)
  * [sixplay] Add support for rtlmost.hu (#21405)
  * [youtube] Hardcode codec metadata for av01 video only formats (#21381)
  * [toutv] Update client key (#21370)
  * [biqle] Add support for new embed domain
  * [cbs] Improve DRM protected videos detection (#21339)
* Sun May 26 2019 Luigi Baldoni <aloisio@gmx.com>
- Split completions into subpackages
* Tue May 21 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2019.05.20
  * svtplay: Update API URL
* Sat May 11 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2019.05.11
  * youtube: Fix channel id extraction
  * openload: Add support for verystream.com
  * byutv: Add support for DVR videos
* Tue Apr 30 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2019.04.30
  * twitch: prefer source format
  * youtube: extract additional meta data from video description
    on youtube music videos
* Wed Apr 24 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to new upstream release 2019.04.24
  * youtube: Fix extraction (#20758, #20759, #20761, #20762, #20764, #20766,
    [#20767], #20769, #20771, #20768, #20770)
  * toutv: Fix extraction and extract series info (#20757)
  * vrv: Add support for movie listings (#19229)
  * youtube: Print error when no data is available (#20737)
  * soundcloud: Add support for new rendition and improve extraction (#20699)
  * ooyala: Add support for geo verification proxy
  * nrl: Add support for nrl.com (#15991)
  * vimeo: Extract live archive source format (#19144)
  * vimeo: Add support for live streams and improve info extraction (#19144)
  * ntvcojp: Add support for cu.ntv.co.jp
  * nhk: Extract RTMPT format
  * nhk: Add support for audio URLs
  * udemy: Add another course id extraction pattern (#20491)
  * openload: Add support for oload.services (#20691)
  * openload: Add support for openloed.co (#20691, #20693)
  * bravotv: Fix extraction (#19213)
- Unify previous changelogs so that pre_checkin.sh do not break them
* Fri Apr 19 2019 Luigi Baldoni <aloisio@gmx.com>
- youtube-dl: Switch build to python3
- python-youtube-dl:  Fix runtime requirements
* Tue Apr 16 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2019.04.17
  * openload: Randomize User-Agent
  * yahoo: add support GYAO episode URLs
  * yahoo: add support for streaming.yahoo.co.jp
  * cbs: extract smpte and vtt subtitles
  * streamango: add support for streamcherry.com
* Sat Apr  6 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2019.04.07
  * mediasite: Add support for dashed ids and named catalogs
  * YoutubeDL: Add ffmpeg_location to post processor options
  * gaia: add support for authentication
  * adobeconnect: Add new extractor
  * vk: use a more unique video id
  * adn: fix extraction and add support for positioning styles
  * teamcoco: fix extraction and add suport for subdomains
  * youtube: extract srv[1-3] subtitle formats
  * hbo: fix extraction and extract subtitles
  * vrv: add basic support for individual movie links
  * ruutu: Add support for audio podcasts
- Require full python [boo#1121694, boo#1120842]
* Mon Apr  1 2019 Sebastien CHAVAUX <seb95passionlinux@opensuse.org>
- Update to new upstream release 2019.04.01
  * [utils] Improve int_or_none and float_or_none (#20403)
  * Check for valid --min-sleep-interval when --max-sleep-interval is specified
    (#20435)
  * [weibo] Extend URL regular expression (#20496)
  * [xhamster] Add support for xhamster.one (#20508)
  * [mediasite] Add support for catalogs (#20507)
  * [teamtreehouse] Add support for teamtreehouse.com (#9836)
  * [ina] Add support for audio URLs
  * [ina] Improve extraction
  * [cwtv] Fix episode number extraction (#20461)
  * [npo] Improve DRM detection
  * [pornhub] Add support for DASH formats (#20403)
  * [svtplay] Update API endpoint (#20430)
* Sun Mar 17 2019 Jan Engelhardt <jengelh@inai.de>
- Update homepage and download URLs
- Update to new upstream release 2019.03.18
  * Add extractor for yandexvideo
* Fri Mar  8 2019 Sebastien CHAVAUX <seb95passionlinux@opensuse.org>
- Update to new upstream release 2019.03.09
  * [extractor/common] Use compat_etree_Element
  * [compat] Introduce compat_etree_Element
  * [extractor/common] Fallback url to base URL for DASH formats
  * [extractor/common] Do not fail on invalid data while parsing F4M manifest
    in non fatal mode
  * [extractor/common] Return MPD manifest as format's url meta field (#20242)
  * [utils] Strip #HttpOnly_ prefix from cookies files (#20219)
  * [francetv:site] Relax video id regular expression (#20268)
  * [toutv] Detect invalid login error
  * [toutv] Fix authentication (#20261)
  * [urplay] Extract timestamp (#20235)
  * [openload] Add support for oload.space (#20246)
  * [facebook] Improve uploader extraction (#20250)
  * [bbc] Use compat_etree_Element
  * [crunchyroll] Use compat_etree_Element
  * [npo] Improve ISM extraction
  * [rai] Improve extraction (#20253)
  * [paramountnetwork] Fix mgid extraction (#20241)
  * [libsyn] Improve extraction (#20229)
  * [youtube] Add more invidious instances to URL regular expression (#20228)
  * [spankbang] Fix extraction (#20023)
  * [espn] Extend URL regular expression (#20013)
  * [sixplay] Handle videos with empty assets (#20016)
  * [vimeo] Add support for Vimeo Pro portfolio protected videos (#20070)
* Thu Feb 28 2019 Sebastien CHAVAUX <seb95passionlinux@opensuse.org>
- Update to new upstream release 2019.03.01
  * [downloader/external] Add support for rate limit and retries for wget
  * [downloader/external] Fix infinite retries for curl (#19303)
  * [npo] Fix extraction (#20084)
  * [francetv:site] Extend video id regex (#20029, #20071)
  * [periscope] Extract width and height (#20015)
  * [servus] Fix extraction (#19297)
  * [bbccouk] Make subtitles non fatal (#19651)
  * [metacafe] Fix family filter bypass (#19287)
* Sun Feb 17 2019 Sebastien CHAVAUX <seb95.scou@gmail.com>
- Update to new upstream release 2019.02.18
  * [tvp:website] Fix and improve extraction
  * [tvp] Detect unavailable videos
  * [tvp] Fix description extraction and make thumbnail optional
  * [linuxacademy] Add support for linuxacademy.com (#12207)
  * [bilibili] Update keys (#19233)
  * [udemy] Extend URL regular expressions (#14330, #15883)
  * [udemy] Update User-Agent and detect captcha (#14713, #15839, #18126)
  * [noovo] Fix extraction (#19230)
  * [rai] Relax URL regular expression (#19232)
  * [vshare] Pass Referer to download request (#19205, #19221)
  * [openload] Add support for oload.live (#19222)
  * [imgur] Use video id as title fallback (#18590)
  * [twitch] Add new source format detection approach (#19193)
  * [tvplayhome] Fix video id extraction (#19190)
  * [tvplayhome] Fix episode metadata extraction (#19190)
  * [rutube:embed] Fix extraction (#19163)
  * [rutube:embed] Add support private videos (#19163)
  * [soundcloud] Extract more metadata
  * [trunews] Add support for trunews.com (#19153)
  * [linkedin:learning] Extract chapter_number and chapter_id (#19162)
* Tue Feb 12 2019 Sebastien CHAVAUX <seb95passionlinux@opensuse.org>
- Update to new upstream release 2019.02.08
  * [utils] Improve JSON-LD regular expression (#18058)
  * [YoutubeDL] Fallback to ie_key of matching extractor while making
    download archive id when no explicit ie_key is provided (#19022)
  * [malltv] Add support for mall.tv (#18058, #17856)
  * [spankbang:playlist] Add support for playlists (#19145)
  * [spankbang] Extend URL regular expression
  * [trutv] Fix extraction (#17336)
  * [toutv] Fix authentication (#16398, #18700)
  * [pornhub] Fix tags and categories extraction (#13720, #19135)
  * [pornhd] Fix formats extraction
  * [pornhd] Extract like count (#19123, #19125)
  * [radiocanada] Switch to the new media requests (#19115)
  * [teachable] Add support for courses.workitdaily.com (#18871)
  * [vporn] Remove extractor (#16276)
  * [soundcloud:pagedplaylist] Add ie and title to entries (#19022, #19086)
  * [drtuber] Extract duration (#19078)
  * [soundcloud] Fix paged playlists extraction, add support for albums and
  update client id
  * [soundcloud] Update client id
  * [drtv] Improve preference (#19079)
  * [openload] Add support for openload.pw and oload.pw (#18930)
  * [openload] Add support for oload.info (#19073)
  * [crackle] Authorize media detail request (#16931)
* Sun Jan 27 2019 Sebastien CHAVAUX <seb95passionlinux@opensuse.org>
- Update to new upstream release 2019.01.27
  * [extractor/common] Extract season in _json_ld
  * [postprocessor/ffmpeg] Fallback to ffmpeg/avconv for audio codec detection
    (#681)
  * [vice] Fix extraction for locked videos (#16248)
  * [wakanim] Detect DRM protected videos
  * [wakanim] Add support for wakanim.tv (#14374)
  * [usatoday] Fix extraction for videos with custom brightcove partner id
    (#18990)
  * [drtv] Fix extraction (#18989)
  * [nhk] Extend URL regular expression (#18968)
  * [go] Fix Adobe Pass requests for Disney Now (#18901)
  * [openload] Add support for oload.club (#18969)
* Tue Jan 15 2019 Sebastien CHAVAUX <seb95passionlinux@opensuse.org>
- Update to new upstream release 2019.01.16
  * Fix uplynk ad skipping
  * Extractors:
  * youtube: Skip unsupported adaptive stream type
  * youtube: Extract DASH formats from player response
  * Fix extraction for funimation, skylinewebcams
  * curiositystream: Add support for non app URLs
  * Add support for playplus.com
* Thu Jan 10 2019 Sebastien CHAVAUX <seb95passionlinux@opensuse.org>
- Update to new upstream release 2019.01.10
  * Embed subtitles with non-standard language codes
  * Add language codes replaced in 1989 revision of ISO 639
    to ISO639Utils
  * youtube: Extract live HLS URL from player response
  * Add support for outsidetv.com, National Geographic,
    playplus.tv, gaia.com, hungama.com
  * Use JW Platform Delivery API V2 and add support for more URLs
* Mon Jan  7 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2019.01.02
  * Add support for classic.ardmediathek.de,
    learning.oreilly.com, embed.acast.com, Scripps Networks watch
    domains, lecturio.de, npostart.nl, play.acast.com,
    subscription.packtpub.com.
* Sat Dec 22 2018 sean@suspend.net
- Update to new upstream releease 2018.12.17
  * ard: Improve geo restricted videos extraction
  * ard: Fix subtitles extraction
  * ard: Improve extraction robustness
  * ard: Relax URL regular expression
  * acast: Add support for embed.acast.com/play.acast.com
  * iprima: Relax URL regular expression
  * vrv: Fix initial state extraction
  * youtube: Fix mark watched
  * safari: Add support for learning.oreilly.com
  * youtube: Fix multifeed extraction
  * lecturio: Improve subtitles extraction
  * uol: Fix format URL extraction
* Tue Dec 11 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2018.12.09
  * wistia: Add support for fast.wistia.com
  * vimeo: Add support for VHX subtitles (Vimeo OTT)
  * aenetworks: add support for History Vault
  * teachable: Add support for teachable based platform sites
* Fri Nov 23 2018 sschricker@suse.de
- Update to new upstream release 2018.11.23
  * [mixcloud] Fallback to hardcoded decryption key
  * [nbc:news] Fix article extraction
  * [foxsports] Fix extraction
  * [ciscolive] Add support for ciscolive.cisco.com
  * [nzz] Relax kaltura regex
  * [kaltura] Limit requested MediaEntry fields
  * [americastestkitchen] Add support for zype embeds
  * [nova:embed] Fix extraction
* Sun Nov 18 2018 seb95.scou@gmail.com
- Update to new upstream release 2018.11.18
  * [wwe] Add support for wwe.com
  * [vk] Detect geo restriction
  * [openload] Use original host during extraction
  * [atvat] Fix extraction
  * [rte] Add support for new API endpoint
  * [tnaflixnetwork:embed] Fix extraction
  * [picarto] Use API and add token support
  * [zype] Add support for player.zype.com
  * [vivo] Fix extraction
  * [ruutu] Update API endpoint
* Sat Nov 10 2018 mcepl@suse.com
- Update to new upstream release 2018.11.07
  * Add another JS signature function name regex (#18091,
    [#18093], #18094)
  * [facebook] Fix tahoe request (#17171)
  * [cliphunter] Fix extraction (#18083)
  * [youtube:playlist] Add support for invidio.us (#18077)
  * [zattoo] Arrange API hosts for derived extractors (#18035)
  * [youtube] Add fallback metadata extraction from
    videoDetails (#18052)
* Mon Nov  5 2018 sean@suspend.net
- Update to new upstream release 2018.11.03
  * Add support for ehftv.com
  * Add support for twitcasting.tv
  * Add support for oload.fun
  * Add support for linkedin.com/earning
* Sat Oct 13 2018 sean@suspend.net
- Update to new upstream release 2018.10.05
  * Improve authentication (#17762)
  * Fix extraction (#17699)
  * Switch to HTTPS for RpcApi (#17749)
* Mon Sep 10 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2018.09.08
  * ard: Add support for Beta ARD Mediathek
  * crunchyroll: parse vilos media data
* Tue Aug 28 2018 jengelh@inai.de
- Update to new upstream release 2018.08.28
  * nova:embed: Add extractor (closes #17282)
  * Add support for vidzi.nu, vidto.se
  * youtube:playlist: Add support for music album playlists
    (OLAK5uy_ prefix)
* Sat Aug 25 2018 jengelh@inai.de
- Update to new upstream release 2018.08.22
  * raywenderlich: Adapt to site redesign
  * imdb: Fix extension extraction
* Sun Aug  5 2018 jengelh@inai.de
- Update to new upstream release 2018.08.04
  * viqeo: add extractor
* Mon Jul 30 2018 jengelh@inai.de
- Update to new upstream release 2018.07.29
  * crunchyroll/playlist: restrict URL regular expression
  * ted: fix extraction for videos without nativeDownloads
  * vk: Fix extraction for inline-only videos
* Thu Jul 26 2018 jengelh@inai.de
- Update to new upstream releases 2018.07.21
  * pbs: Add another cove id pattern
  * dailymotion: add support for password protected videos
  * vidzi: Fix extraction
  * Prefer ffmpeg over avconv by default
  * dctptv: Restore extraction based on REST API
  * nrktv: Add support for new episode URL schema
  * nrktv: Add support for new season and serie URL schema
* Wed Jun  6 2018 jengelh@inai.de
- Update to new upstream release 2018.06.04
  * tumblr: add support for authentication
  * soundcloud: detect format extension
  * rtmp: gracefully handle live streams interrupted by user
  * openload: add support for oload.win and oload.download
  * facebook: add support for tahoe player videos
  * youtube: extract track and artist
* Tue May 29 2018 jengelh@inai.de
- Update to new upstream release 2018.05.26
  * imgur: Fix extraction
  * hidive: add support for authentication
  * nbc: add support for stream.nbcsports.com
* Fri May 18 2018 jengelh@inai.de
- Update to new upstream release 2018.05.18
  * youtube: fix extraction for embed restricted live streams
  * youtube: Make uploader extraction non fatal
  * youtube: Improve format filesize extraction
  * youtube: fix hd720 format position
* Wed May  2 2018 jengelh@inai.de
- Update to new upstream release 2018.05.01
  * Restart download if .ytdl file is corrupt
  * Add support for old.reddit.com URLs
* Wed Apr 25 2018 seb95.scou@gmail.com
- Update to new upstream release 2018.04.25
  * Fix match_str for boolean meta fields
  * Add support for pandoc 2 and disable smart extension (#16251)
  * Fix typo in media extension compatibility checker (#16215)
  * Recognize IPv6 stream URLs (#16136, #16137, #16205, #16246,
  [#16250])
  * Extract is_live according to status (#16259)
  * Relax URL regular expression (#16258)
  * Remove extractor (#16256)
  * Fix extraction (#16254)
  * Add ability to authenticate with cookies
  * Implement lazy playlist extraction (#10184)
  * Add support for TV channel live streams (#15279, #15809)
  * Fix video extraction (#15931)
  * Fix extraction (#15227)
  * Add support for nickjr.nl (#16230)
  * Fix metadata extraction
  * Add support for generic embeds (#16134, #16154)
  * Extract new azure URLs (#16223)
  * Fix extraction (#16217)
  * Improve embeds detection (#16201)
  * Fix extraction (#16119)
  * Skip DRM asset types (#16104)
* Mon Apr 16 2018 jengelh@inai.de
- Update to new upstream release 2018.04.16
  * Add support for picarto.tv
  * Add support for mobile URLs
* Sat Apr 14 2018 seb95.scou@gmail.com
- Update to new upstream release 2018.04.09
  * Do not save/restore console title while simulate
  * Relax JSON-LD context check
  * Add support for tube8 embeds
  * Add support for share-videos.se embeds
  * Extend URL regular expression
  * Bypass mature content check
  * Extract more metadata
  * Fix extraction
  * Fix extraction
  * Fix title extraction
  * Extend URL regular expression
  * Add support for oload.xyz
  * Relax stream URL regular expression
  * Fix extraction
  * Add support for season URLs
  * Add support for series
* Mon Feb 26 2018 jengelh@inai.de
- Update to new upstream release 2018.02.26
  * veoh: Add support for embed URLs
* Mon Feb  5 2018 jengelh@inai.de
- Update to new upstream release 2018.02.04
  * Randomize HTTP chunk size
  * Fix HTTP/302 infinite loops by not reusing requests
  * brightcove: Pass embed page URL as referrer
  * youtube: enforce using chunked HTTP downloading for DASH formats
* Tue Jan 30 2018 jengelh@inai.de
- Update to new upstream release 2018.01.27
  * JWPlatform: Support iframes
  * openload: Add support for openload.link
  * utils: add hvc1 codec code to parse_codecs
  * downloader/fragment: Commit part file after each fragment In
    order to obtain correct resume_len on next iteration
  * mailru: Add support for embed URLs
  * downloader/fragment: Encode filename of fragment being
    removed
  * extractor/common: Introduce uploader, uploader_id and
    uploader_url meta fields for playlists
  * openload: Add support for oload.stream
  * extractor/common: Improve DASH formats extraction for jwplayer
* Tue Nov 14 2017 astieger@suse.com
- update to 2017.11.15:
  * many update to various downloaders and extractors
* Mon Sep 25 2017 jengelh@inai.de
- Update to new upstream release 2017.09.24
  * YoutubeDL: write raw subtitle files
  * laola1tv: Add support for tv.ittf.com
  * liveleak: Support multi-video pages
  * googledrive: Add support for subtitles
  * googledrive: Add support for source format
  * bbccouk: Add support for w-prefixed ids
  * charlierose: Add support for episodes
  * manyvids: Add support for preview videos
  * animeondemand: Add support for flash videos
  * downloader/fragment: Restart inconsistent incomplete fragment downloads
  * orf: Add new extractor for f4m stories
  * twitch: Add support for go.twitch.tv URLs
  * heise: Add support for YouTube embeds
  * lynda: Add support for educourse.ga
  * options: Accept lrc as a subtitle conversion target format
  * twitter: Add support for user_id-less URLs
* Thu Aug 17 2017 jengelh@inai.de
- Update to new upstream release 2017.08.18
  * Sanitize byte string format URLs
  * Make sure format id is not empty
* Mon Aug  7 2017 jengelh@inai.de
- Update to new upstream release 2017.08.06
  * amcnetworks: Make rating optional
  * yandexdisk: Add extractor
  * ard: Add support for liveS
  * pbs: Add support for new URL schema
  * vidme: Extract DASH and HLS formats
* Mon Jul 24 2017 jengelh@inai.de
- Update to new upstream release 2017.07.23
  * Remove extractor for yam
  * spiegel:article: Add support for nexx iframe embeds
* Wed Jul  5 2017 jengelh@inai.de
- Update to new upstream release 2017.07.02
  * youtube: improve chapters extraction (closes #13247)
  * youtube: adapt to new automatic captions rendition
* Thu Jun  1 2017 jengelh@inai.de
- Update to new upstream release 2017.05.29
  * youtube: fix DASH manifest signature verification
* Mon May 22 2017 jengelh@inai.de
- Update to new upstream release 2017.05.18.1
  * jsinterp: Add support for quoted names and indexers
* Sun May 21 2017 aloisio@gmx.com
- Made sure we don't ship the upstream binary
* Wed May 17 2017 jengelh@inai.de
- Update to new upstream release 2017.05.14
  * youtube: fix authentication
* Sat Apr 29 2017 jengelh@inai.de
- Update to new upstream release 2017.04.28
  * youtube: remove explicit preference for audio-only and
    video-only formats in order not to break sorting when new
    formats appear.
  * youtube: recognize new locale-based player URLs
  * youtube: recognize another HTML5 player URL
* Tue Apr 11 2017 jengelh@inai.de
- Update to new upstream release 2017.04.11
  * vshare: add extractor
* Fri Apr  7 2017 jengelh@inai.de
- Update to new upstream release 2017.04.03
  * youtube: recognize TL playlists
  * youtube: add format info for itag 325 and 328
  * zdf: fix extraction (ticket 12117)
  * heise: support videos embedded in any article
  * youtube-dl postprocessor: add support for FLAC
* Wed Feb  1 2017 jengelh@inai.de
- Update to new upstream release 2017.01.31
  * cmt,mtv,southpark: Add support for episode URLs
  * youtube: Fix extraction for domainless player URLs
* Thu Jan 26 2017 jengelh@inai.de
- Update to new upstream release 2017.01.25
  * Support tv.naver.com links
  * Support openload embeds
* Tue Jan 17 2017 jengelh@inai.de
- Update to new upstream release 2017.01.16
  * Make openload.co work again
* Thu Jan 12 2017 jengelh@inai.de
- Update to new upstream release 2017.01.10
  * Update youtube extraction strategy
* Mon Jan  9 2017 jengelh@inai.de
- Update to new upstream release 2017.01.08
  * add support for arkena.com, for comedycentral HLS video
* Sun Jan  1 2017 jengelh@inai.de
- Update to new upstream release 2016.12.31
  * acast: Fix broken audio URL and timestamp extraction
  * brightcove:legacy: Improve embeds detection
  * showroomlive, videa: Add extractor
* Tue Dec 27 2016 jengelh@inai.de
- Update to new upstream release 2016.12.22
  * prosiebensat1: extract dash formats
  * openload: recognize oload.tv
  * extractor/common: Recognize DASH formats in html5 media entries
  * brightcove:new: skip widevine classic videos
  * rtl2: extract more formats and metadata
* Fri Dec  9 2016 jengelh@inai.de
- Update to new upstream release 2016.12.09
  * cbslocal: Support newyork.cbslocal.com
  * viki: Prefer hls
  * thisoldhouse: Recognize /tv-episode/ URLs and update _TESTS
* Tue Nov 22 2016 jengelh@inai.de
- Update to new upstream release 2016.11.22
  * amcnetworks: Recognize more BBC America URLs
* Thu Nov 17 2016 jengelh@inai.de
- Update to new upstream release 2016.11.18
  * fix openload extraction
* Mon Nov 14 2016 jengelh@inai.de
- Update to new upstream release 2016.11.14.1
  * audioboom: Recognize /posts/ URLs
  * afreecatv: Add support for vod.afreecatv.com
* Fri Nov 11 2016 jengelh@inai.de
- Update to new upstream release 2016.11.08.1
  * Improve mpd base URL extraction
  * Add extractor for nicknight, vzaar, fox9
  * Add support for ISM manifests
* Tue Nov  1 2016 jengelh@inai.de
- Update to new upstream release 2016.10.31
  * openload: Support subtitles
  * download/hls: Delegate downloading to ffmpeg for live streams
  * brightcove:new: add support for live streams
  * jwplatform: Support DASH streams
  * twitch:stream: Add support for rebroadcasts
* Tue Sep 27 2016 jengelh@inai.de
- Update to new upstream release 2016.09.24
  * prosiebensat1: Add support for kabeleinsdoku
  * ustream: Support HLS streams
  * fox, cartoonnetwork: add support for Adobe Pass auth
* Wed Sep 21 2016 jengelh@inai.de
- Update to new upstream release 2016.09.19
  * jwplatform: Use js_to_json to detect more JWPlayers
* Sun Sep 18 2016 jengelh@inai.de
- Update to new upstream release 2016.09.15
  * Add extractor for abc:iview
  * eagleplatform: improve detection of embedded videos
  * pluralsight: add support for subtitles
* Mon Aug 22 2016 jengelh@inai.de
- Update to new upstream release 2016.08.22
  * Recognize m3u8 manifests in HTML5 multimedia tags
* Tue Aug 16 2016 jengelh@inai.de
- Update to new upstream release 2016.08.13
  * pbs: dad test for videos with undocumented http formats
  * crunchyroll: add support for HLS
* Sat Aug  6 2016 jengelh@inai.de
- Update to new upstream release 2016.08.06
  * vodplatform: Add new extractor
  * limelight: extract http formats
* Mon Jul 25 2016 jengelh@inai.de
- Update to new upstream release 2016.07.24
  * onet, dcn, telegraaf, arkena: enable dash formats
* Thu Jun 30 2016 jengelh@inai.de
- Update to new upstream release 2016.07.01
  * youtube: fix ID 141 format tests
* Mon Jun 27 2016 jengelh@inai.de
- Update to new upstream release 2016.06.23.1
  * Improved jwplayer support
* Wed May 18 2016 jengelh@inai.de
- Update to new upstream release 2016.05.16
  * groupon: add support for Youtube embeds
* Wed May  4 2016 jengelh@inai.de
- Update to new upstream release 2016.05.01
  * Add support for tagesschau playlists
* Wed Apr 27 2016 jengelh@inai.de
- Update to new upstream release 2016.04.24
  * Add new extractor for nhl, today.com, mgtv, dispeak,
  instagram, tdslifeway.
  * mixcloud: Added support for user uploads, playlists, favorites
  and listens.
* Mon Apr 18 2016 jengelh@inai.de
- Update to new upstream release 2016.04.13
  * Add extractors for cliprs, presstv, auroravid, zdnet videos, cbs
* Mon Apr  4 2016 jengelh@inai.de
- Update to new upstream release 2016.04.01
  * brightcove: Support alternative BrightcoveExperience
* Fri Mar 25 2016 jengelh@inai.de
- Update to new upstream release 2016.03.25
  * New extractor for mnet, udemy, thescene, biobiotv, cda.pl, hbo
  * Support Vine embeddings
* Sat Mar 19 2016 jengelh@inai.de
- Update to new upstream release 2016.03.18
  * fix DASH format sorting
  * Add new extractor for rice, tv3, once
* Mon Mar 14 2016 jengelh@inai.de
- Update to new upstream release 2016.03.14
  * add new extractor for usatoday, minoto
  * add external rtsp and mms protocol downloader
* Tue Mar  8 2016 jengelh@inai.de
- Update to new upstream release 2016.03.06
  * unspecified set of fixes and improvements
* Tue Mar  1 2016 jengelh@inai.de
- Update to new upstream release 2016.03.01
  * Add support for dplay.no
  * imdb: recognize 1080p formats
* Sun Feb 14 2016 jengelh@inai.de
- Update to new upstream release 2016.02.13
  * vevo: add support for DASH formats
* Mon Feb  1 2016 jengelh@inai.de
- Update to new upstream release 2016.02.01
  * youtube: added vcodec/acodec/abr for multiple itags
  * vidzi: fix extraction
  * schooltv: Add extractor for SchoolTV playlists
* Mon Jan 25 2016 jengelh@inai.de
- Update to new upstream release 2016.01.23
  * subtitle support for svtplay
  * add extractor for arte:cinema, lemonde, weiqitv
* Tue Jan 19 2016 jengelh@inai.de
- Update to new upstream release 2016.01.16
  * cwtv: add new extractor
  * add support for fyi.tv, aetv.com, mylifetime.com, 7tv.de
* Sat Jan  9 2016 jengelh@inai.de
- Update to new upstream release 2016.01.09
* Sat Dec 26 2015 mailaender@opensuse.org
- Update to new upstream release 2015.12.23
* Wed Dec 16 2015 jengelh@inai.de
- Update to new upstream release 2015.12.13
  * Add cookie and referer in headers
  * Updates for VEVO service
* Sat Nov 28 2015 jengelh@inai.de
- Update to new upstream release 2015.11.27.1
  * Remove Accept-encoding from HLS headers passed to ffmpeg
* Thu Nov 26 2015 jengelh@inai.de
- Update to new upstream release 2015.11.24
  * Again support new youtube js code
* Mon Nov 16 2015 aloisio@gmx.com
- Update to new upstream release 2015.11.15
  * Added extrator for nowtv list
* Thu Nov 12 2015 jengelh@inai.de
- Update to new upstream release 2015.11.10
  * youtube: support new base.js html5 player
* Mon Oct 26 2015 jengelh@inai.de
- Update to new upstream release 2015.10.24
  * Support age restricted channels in youtube
* Sun Oct 11 2015 jengelh@inai.de
- Update to new upstream release 2015.10.09
  * rtmp: respect --no-continue option
  * vimeo: avoid failure when no HLS type streams are available
* Thu Sep 24 2015 jengelh@inai.de
- Update to new upstream release 2015.09.22
  * nowness: video extraction and add support serie and playlist ext?.
  * ndr: add support for embeds
  * yahoo: process query result embedded in webpage
* Wed Sep  9 2015 jengelh@inai.de
- Update to new upstream release 2015.09.03
  * downloader/f4m Fragment filenames are now be sanitized.
  * Improvements to mtvservices: support for news, catch more
  georestriction errors, title extraction under python2.
  * Check for ScreenwaveMedia embeddings. Warn when falling back to
  a hardcoded list of streams.
  * youtube was missing format details for 60fps DASH formats.
  * f4m: add missing imports
  * hls: properly encode fragment filename
* Mon Aug 24 2015 jengelh@inai.de
- Update to new upstream release 2015.08.16.1
  * youtube: search_url extraction.
  * youtube: Expand _VALID_URL to support vid.plus.
* Sat Aug 15 2015 jengelh@inai.de
- Avoid pandoc requirement when using regular release tarballs
* Sun Aug  9 2015 mailaender@opensuse.org
- Update to new upstream release 2015.08.06.1
  * Add support for sportschau.de
  * Add support for YouTube multifeed videos
  * Add support for SoundCloud reposts
* Fri Jul 31 2015 jengelh@inai.de
- Update to new upstream release 2015.07.28
  * Use 'vp8' and 'vp9' in lowercase
  * Add support for direct bbc.co.uk embeds
* Mon Jul 20 2015 jengelh@inai.de
- Update to new upstream release 2015.07.18
  * myspass: resolve download failure
* Sun Jul 19 2015 jengelh@inai.de
- Update to new upstream release 2015.07.07
  * qqmusic: add support for playlists
* Mon Jul  6 2015 benoit.monin@gmx.fr
- update to version 2015.07.04:
  * new handlers for MovieFap, SnagFilms, ThisAmericanLife,
    TwitterCard
* Tue Jun 30 2015 benoit.monin@gmx.fr
- update to version 2015.06.25:
  * new handlers for AdobeTVVideo, DailymotionCloud, OnionStudios,
    Pinkbike, XHamsterEmbed
* Wed Jun 17 2015 jengelh@inai.de
- Update to new upstream release 2015.06.15
  * New handlers for dramafever, dramafever:series, FiveTV, iqiyi,
  Ruutu, TVC, TVCArtic.
* Sat Jun  6 2015 jengelh@inai.de
- Update to new upstream release 2015.06.04.1
  * Improved handler for spiegel.tv
* Sat May 30 2015 benoit.monin@gmx.fr
- update to version 2015.05.29:
  * new handlers for AppleDaily, KarriereVideos, NowTV,
    viki:channel
  * removed handlers for AppleDailyAnimationNews,
    AppleDailyRealtimeNews, Firedrive, RTLnow, Sockshare
* Sat May 23 2015 benoit.monin@gmx.fr
- update to version 2015.05.20:
  * new handlers for ESPN, OoyalaExternal, SportBoxEmbed, TV2,
    TV2Article
* Mon May 18 2015 benoit.monin@gmx.fr
- update to version 2015.05.15:
  * new handlers for N-JOY, qqmusic:toplist, southparkstudios.dk,
    TMZArticle, VoiceRepublic
* Tue May 12 2015 benoit.monin@gmx.fr
- update to version 2015.05.10:
  * new handlers for bt:article, bt:vestlendingen, life:embed,
    NYTimesArticle, southpark.nl, SVT, Xstream
* Wed May  6 2015 benoit.monin@gmx.fr
- update to version 2015.05.04:
  * new handlers for BaiduVideo, FoxSports, PhilharmonieDeParis
  * removed handler for Grooveshark
* Mon Apr 27 2015 benoit.monin@gmx.fr
- update to new upstream release 2015.04.26:
  * new handlers for Gfycat, MegaVideoz, SenateISVP,
    southpark.cc.com:español
* Sat Apr 18 2015 benoit.monin@gmx.fr
- update to new upstream release 2015.04.17:
  * fix unicode warning about the configuration file
  * new handlers for CrooksAndLiars, QQMusic, QQMusicAlbum,
    QQMusicSinger, Srf
* Sat Apr 11 2015 benoit.monin@gmx.fr
- update to new upstream release 2015.04.09:
  * fix invalid warning about missing ssl certificates
  * new handlers for Gamersyde, PornoVoisines, RadioJavan,
    SpankBang, UDNEmbed
* Fri Apr  3 2015 benoit.monin@gmx.fr
- update to new upstream release 2015.04.03:
  * new handlers for 22tracks:genre, 22tracks:track, DHM, Dumpert,
    miomio.tv, NBCSports, NBCSportsVPlayer, safari, safari:course,
    Varzesh3, Vessel
* Sat Mar 28 2015 jengelh@inai.de
- Update to new upstream relase 2015.03.24
  * Support and URL updates for ntimes, nrk, videomega, dailyshow.
* Wed Mar 11 2015 benoit.monin@gmx.fr
- update to 2015.03.09:
  * new handlers for AirMozilla, chirbit, chirbit:profile,
    EaglePlatform, Gazeta, Kaltura, Letv, LetvPlaylist, LetvTv,
    Odnoklassniki, orf:iptv, Pladform, Playwire, Puls4, R7,
    soundgasm:profile
* Sat Feb 21 2015 benoit.monin@gmx.fr
- update to 2015.02.21:
  * new command line options:
    + --no-color  Do not emit color codes in output
    + --match-filter FILTER  (Experimental) Generic video filter
    + --hls-prefer-native  (experimental) Use the native HLS
    + --ffmpeg-location PATH  Location of the ffmpeg/avconv binary
  * new handlers for 1tv, Camdemy, CamdemyFolder, CBSSports,
    Embedly, History, Imgur, media.ccc.de, NationalGeographic,
    npo.nl:radio, npo.nl:radio:fragment, PornHubPlaylist, rtl.nl,
    Sandia, TV4, Yam, Zapiks
* Mon Feb  9 2015 benoit.monin@gmx.fr
- update to new upstream release 2015.02.09.3:
  * various fixes
  * new and updated handlers for Abc7News, Aftenposten,
    AlphaPorno, AppleDailyAnimationNews, AppleDailyRealtimeNews,
    AtresPlayer, ATTTechChannel, audiomack:album, CNNArticle,
    CollegeRama, CtsNews, DctpTv, DRBonanza, EchoMsk, EroProfile,
    Giga, HearThisAt, HellPorno, HistoricFilms, hitbox, Karaoketv,
    LnkGo, n-tv.de, Nerdist, Netzkino, NextMedia,
    NextMediaActionNews, nhl.com:news, : NHL newsnpo.nl:live,
    ntv.ru, OpenFilm, orf:fm4, : radio FM4radiobremen, Rte, RTL2,
    rutube:embed, SRMediathek, StreetVoice, SVTPlay, TeleTask,
    TestTube, tvp.pl:Series, Tweakers, Twitch, vier, vier:videos,
    WebOfStories, WSJ, Xuite, XXXYMovies
- call 'make clean' to avoid packaging a prebuild binary
- add pandoc as buildRequires to generate the manpage
* Sat Jan 24 2015 benoit.monin@gmx.fr
- update to new upstream release 2015.01.23.4:
  * numerous improvements
  * new handlers for 24video, AdobeTV, AlJazeera, Azubu, Bet, Bpb,
    BuzzFeed, Cinchcast, ComCarCoff, dvtv, Foxgay, FoxNews,
    GiantBomb, Groupon, Minhateca, MySpace:album, MyVidster,
    NerdCubedFeed, radio.de, Restudy, RTP, ScreencastOMatic,
    ScreenwaveMedia, Tass, TeamFour, TeleBruxelles, TMZ,
    TrailerAddict, TuneIn, vk.com:user-videos, XMinus, YesJapan,
    ZDFChannel, zingmp3:album, zingmp3:song
- add new buildRequires to generate the readme:
  * python-devel
  * python-xml
* Sat Nov 22 2014 jengelh@inai.de
- Update to new upstream release 2014.11.21.1
  * Update handlers for vh1, comedycentral, stanfordoc
  * correct OptionGroup invocation for Python 3
  * Fix writing to paths with unicode characters
  * rtlxl: Use m3u8 streams instead of f4m
  * youtube: Add webm audio formats
* Wed Nov 19 2014 jengelh@inai.de
- Update to new upstream release 2014.11.16
  * Modernize handlers for new URLs at spiegel.tv, blip.tv,
  and some others.
* Sun Nov  9 2014 aloisio@gmx.com
- Update to new upstream release 2014.11.04
  * Numerous improvements
* Mon Aug 11 2014 jengelh@inai.de
- Update to new upstream release 2014.08.10
  * appletrailers: Support height-less videos
  * ard: Show error message if video is no longer available
  * fm4, gamestar, mojvideo, tvplay, ubu, xboxclips:
  add new extractors
* Sat Jul 19 2014 jengelh@inai.de
- Update to new upstream release 2014.07.15
  * Add support for Spike mobile URLs, aftonbladet.se, Playvid,
  wdr.de, concert.arte.tv, parliamentlive.uk, on.aol.com, xbef,
  rts.ch, byutv.org, and many more
* Sat Mar  8 2014 jengelh@inai.de
- Update to new upstream release 2014.03.07.1
  * Add an Info Extractor (IE) for non-{password protected}
  GDC Vault videos
  * Add support for video from embed.ly, mail.ru, ceskatelevize.cz,
  tvigle.ru, 13.cl, authenticated videos
  * Fixed segment extraction for ORF
  * Add support for Youtube search result URLs
* Mon Mar  3 2014 jengelh@inai.de
- Update to new upstream release 2014.02.28
  * miscellaneous fixes to make YT downloading work again (bnc#866153)
  * support for ComedyCentral clips
  * corrected Vimeo description fetching
  * --verbose now shows more environment information
  * --no-post-overwrites now takes an argument
  * New engines: NBA, JustinTV, FunnyOrDie, TweetReel, Steam, Ustream
* Sun Jun  2 2013 jengelh@inai.de
- Update to new upstream release 2013.05.23
  * Add support for Howcast, Vine, Teamcoco, Flickr videos
  * Add MyVideo RTMP support
* Sun May 12 2013 jengelh@inai.de
- Reinstate Git-Clone line, and do signature verification
- Totally own bash_completion.d
* Sun May 12 2013 tchvatal@suse.com
- Version bump to 2013.05.10 release which fixes compatibility.
  * Use upstream provided tarballs and versioning.
  * Use upstream Makefile directly to generate everything.
  * Install manpage and bash completion.
  * Do not use hand generated documents but rely on those provided
  by upstream.
* Sat Apr  6 2013 jengelh@inai.de
- Initial package (version 0~20130403) for build.opensuse.org
